#Skriptname:  DBCore.pm
#Funktion:    Funktionen zur MySql Datenbank
#Autor:       Jrg Hfner
#Datum:       24.03.2013
#Argumente:


package DBCore;

use strict;
use DBI;

my $database;
my $DB_DSN;
my $DB_USER;
my $DB_PASSWD;
my $dbh;

# JH--------------------------------------------------------------------- 
# Verbindung zur Datenbank herstellen
# -----------------------------------------------------------------------
sub DBConnect{
  $database = shift;
  $DB_DSN = shift;  
  $DB_USER = shift;
  $DB_PASSWD = shift;
  
  $dbh = DBI->connect($DB_DSN, $DB_USER, $DB_PASSWD, {PrintError => 0, RaiseError => 0, AutoCommit => 1 }) 
                       or die failLog ("Fehler bei Datenbankverbindung-> DSN=$DB_DSN -- USER=$DB_USER -- PASS=$DB_PASSWD $!");
}

# JH--------------------------------------------------------------------------- 
# Kappt die Verbindung zur Datenbank
# ----------------------------------------------------------------------------- 
sub DBDisc{
  $dbh->disconnect;
}


# ----------------------------------------------------------------------- 
# hier werden die aufgetretenen Fehler geloggt
# somit hat der Admin ber alle auftretenden Fehler eine bersicht
# ----------------------------------------------------------------------- 
sub failLog{
  my $failtext = shift;
  my ($file, $line, $sub) = ( caller(1) )[1,2,3];
                            
  open STDERR, ">>db_error.log" or die "db_error.log: $!";                                       
  print STDERR scalar localtime(time())." -- ".$failtext." -- File:".$file." Line:".$line." $sub\n"; 
  close (STDERR);  
}


# ----------------------------------------------------------------------- 
# bergebenes Statement wird ausgefhrt / Kein Rckgabewert
# -----------------------------------------------------------------------  
sub do{  
  my ($statement, @param) = @_; 
    
  my $sth = $dbh->prepare($statement);
  $sth->execute(@param) or die failLog( $dbh->errstr );
}
  

# ----------------------------------------------------------------------- 
# bergebenes Statement wird ausgefhrt / Rckgabewert Hashref
# ----------------------------------------------------------------------- 
sub get_hash{
  my ($statement, @param) = @_;  
 
  my $sth = $dbh->prepare($statement);
  $sth->execute(@param) or die failLog( $dbh->errstr );
  if(my $zeile = $sth->fetchrow_hashref()){
    $sth->finish; 
    return $zeile;
  } 
  return 0; 
}


# ----------------------------------------------------------------------- 
# bergebenes Statement wird ausgefhrt / Rckgabewert Array mit Hash
# ----------------------------------------------------------------------- 
sub get_hasharray{
  my ($statement, @param) = @_;  
  
  my $sth = $dbh->prepare($statement);
  $sth->execute(@param) or die failLog( $dbh->errstr );
  my @erg;
  while (my $zeile = $sth->fetchrow_hashref()){
    push(@erg,$zeile);
  }
  $sth->finish;
  return @erg; 
}

1;